==> ttcomment-0.0.1.tar.gz: lib/comment_widget/comment_appbar_generator.dart <==
/*
 * @Descripttion: 
 * @version: 
 * @Author: TT
 * @Date: 2021-10-04 16:44:24
 * @LastEditors: ftt
 * @LastEditTime: 2022-04-22 16:08:30
 */

import 'package:flutter/material.dart';

import '../ttcomment.dart';

class AppBarGenerator {
  static PreferredSize getNoramlAppBar(
      {required BuildContext context,
      required String title,
      List<Widget>? actions,
      Widget? titlew,
      Widget? leading,
      bool showback = true,
      double elevation = 0,
      double prferredheight = -1,
      PreferredSizeWidget? bottom,
      Color? textColor,
      Color? leadingIconColor,
      Color? backgroundColor,
      Function()? leadingCallback}) {
    final ModalRoute<dynamic>? parentRoute = ModalRoute.of(context);
    bool canshowback = parentRoute?.canPop ?? false;
    if (prferredheight == -1) {
      prferredheight = 54;
    }

    backgroundColor ??= ThemeColorConfig.confgColor(ColorEnum.colffffff);
    return PreferredSize(
      preferredSize: Size.fromHeight(prferredheight),
      child: AppBar(
        backgroundColor: backgroundColor,
        centerTitle: true,
        actions: actions,
        leading: showback
            ? (canshowback
                ? (leading ??
                    IconButton(
                      icon: Icon(
                        Icons.arrow_back_ios,
                        color: leadingIconColor ??
                            ThemeColorConfig.confgColor(ColorEnum.col010101),
                      ),
                      onPressed:
                          leadingCallback ?? () => Navigator.of(context).pop(),
                    ))
                : null)
            : null,
        title: titlew ??
            Text(
              title,
              style: TextStyle(
                fontSize: 18,
                color: textColor ??
                    ThemeColorConfig.confgColor(
                      ColorEnum.col010101,
                    ),
              ),
            ),
        elevation: elevation,
        bottom: bottom,
        automaticallyImplyLeading: showback,
      ),
    );
  }

  // 判断是否是一级界面
  static bool isfirstPage({required BuildContext context}) {
    bool showback;
    final ModalRoute<dynamic>? parentRoute = ModalRoute.of(context);
    showback = parentRoute?.canPop ?? false;
    return showback;
  }
}

==> ttcomment-0.0.3.tar.gz: lib/comment_widget/comment_appbar_generator.dart <==
/*
 * @Descripttion: 
 * @version: 
 * @Author: TT
 * @Date: 2021-10-04 16:44:24
 * @LastEditors: TT
 * @LastEditTime: 2022-06-21 11:12:31
 */

import 'package:flutter/material.dart';
import 'package:ttcomment/ttcomment.dart';

class AppBarGenerator {
  static PreferredSize getNoramlAppBar(
      {required BuildContext context,
      required String title,
      List<Widget>? actions,
      Widget? titlew,
      Widget? leading,
      bool showback = true,
      double elevation = 0,
      double prferredheight = -1,
      PreferredSizeWidget? bottom,
      Color? textColor,
      Color? leadingIconColor,
      Color? backgroundColor,
      Function()? leadingCallback}) {
    final ModalRoute<dynamic>? parentRoute = ModalRoute.of(context);
    bool canshowback = parentRoute?.canPop ?? false;
    if (prferredheight == -1) {
      prferredheight = 54;
    }

    backgroundColor ??= CommentColorS.colffffff;
    return PreferredSize(
      preferredSize: Size.fromHeight(prferredheight),
      child: AppBar(
        backgroundColor: backgroundColor,
        centerTitle: true,
        actions: actions,
        leading: showback
            ? (canshowback
                ? (leading ??
                    IconButton(
                      icon: Icon(
                        Icons.arrow_back_ios,
                        color: leadingIconColor ?? CommentColorS.col101010,
                      ),
                      onPressed:
                          leadingCallback ?? () => Navigator.of(context).pop(),
                    ))
                : null)
            : null,
        title: titlew ??
            Text(
              title,
              style: TextStyle(
                fontSize: 18,
                color: textColor ?? CommentColorS.col101010,
              ),
            ),
        elevation: elevation,
        bottom: bottom,
        automaticallyImplyLeading: showback,
      ),
    );
  }

  // 判断是否是一级界面
  static bool isfirstPage({required BuildContext context}) {
    bool showback;
    final ModalRoute<dynamic>? parentRoute = ModalRoute.of(context);
    showback = parentRoute?.canPop ?? false;
    return showback;
  }
}
